@@ -13,6 +13,7 @@ class Bot(commands.Bot):
         self.context = None
         self.message = None
         self.reactions = None
+        self.timer = 0.0
         self.game = game
         self.name = name
 
@@ -22,7 +23,7 @@ class Bot(commands.Bot):
             try:
                 self.load_extension(cog)
             except commands.ExtensionAlreadyLoaded:
-                logging.warning(f'{cog} has already been loaded!')
+                logging.warning(f'{cog} has already been loaded.')
 
         await self.change_presence(activity=discord.Game(name=f'{self.game.prefix}{self.name}'),
                                    status=discord.Status.online)
@@ -33,10 +34,15 @@ class Bot(commands.Bot):
             await self.process_commands(message)
 
     async def on_reaction_add(self, reaction: discord.Reaction, user: discord.User):
-        if user.id == self.context.author.id and reaction.message.id == self.message.id and \
-                str(reaction.emoji) in self.reactions:
-            self.game.input.insert(0, reaction.emoji)
-            await self.message.remove_reaction(reaction.emoji, user)
+        try:
+            if str(reaction.emoji) in self.reactions and user.id == self.context.author.id and \
+                    reaction.message.id == self.message.id:
+                self.game.input.insert(0, reaction.emoji)
+                self.timer = time.time()
+
+                await self.message.remove_reaction(reaction.emoji, user)
+        except AttributeError:
+            logging.info('No context or message currently.')
 
     async def on_command_error(self, ctx: commands.Context, exception: discord.DiscordException):
         if not isinstance(exception, commands.CommandNotFound):
@@ -45,12 +51,14 @@ class Bot(commands.Bot):
     async def game_command(self, ctx: commands.Context):
         screen = [[self.game.background] * self.game.screen_size[1] for _ in range(self.game.screen_size[0])]
         self.game.over = False
+        await asyncio.sleep(0.25)
 
         self.context = ctx
         self.message = await ctx.send(self.make_screen(screen))
         await self.add_reactions(self.game.controls)
 
         tick = time.time()
+        self.timer = time.time()
         self.game.draw(screen)
         await self.message.edit(content=self.make_screen(screen))
 
@@ -62,12 +70,13 @@ class Bot(commands.Bot):
 
                 await self.message.edit(content=self.make_screen(screen))
 
-            if self.game.over:
+            if self.game.over or time.time() - self.timer > self.game.timeout:
                 break
             await asyncio.sleep(max(self.game.tick - (time.time() - tick), 0.0))
             tick = time.time()
         await asyncio.sleep(0.25)
         await self.message.clear_reactions()
+        self.game.over = True
         self.context = None
         self.message = None
 
